@@ -2,7 +2,7 @@
  * vinagre-commands.c
  * This file is part of vinagre
  *
- * Copyright (C) 2007 - Jonh Wendell <wendell@bani.com.br>
+ * Copyright (C) 2007,2008 - Jonh Wendell <wendell@bani.com.br>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
+#include <string.h>
 
 #include "vinagre-commands.h"
 #include "vinagre-utils.h"
@@ -286,7 +287,81 @@ vinagre_cmd_bookmarks_del (GtkAction     *action,
     }
 }
 
+/* Make url in about dialog clickable */
+static void
+vinagre_about_dialog_handle_url (GtkAboutDialog *about,
+				 const char     *link,
+				 gpointer        data)
+{
+  GError *error = NULL;
+  gchar  *address, *command;
+
+  VinagreWindow *window = VINAGRE_WINDOW (data);
+
+  if (g_strstr_len (link, strlen (link), "@"))
+    address = g_strdup_printf ("mailto:%s", link);
+  else
+    address = g_strdup (link);
+
+  command = g_strconcat ("gnome-open ", address,  NULL);
+	
+  gdk_spawn_command_line_on_screen (gtk_window_get_screen (GTK_WINDOW (window)),
+				    command,
+				    &error);
+  if (error != NULL) 
+    {
+      vinagre_utils_show_error (error->message, GTK_WINDOW (window));
+      g_error_free (error);
+    }
+
+  g_free (command);
+  g_free (address);
+}
+
 /* Help Menu */
+
+void
+vinagre_cmd_help_contents (GtkAction     *action,
+			   VinagreWindow *window)
+{
+  GError *error = NULL;
+  char *command;
+  const char *lang;
+  char *uri = NULL;
+  int i;
+
+  const char * const * langs = g_get_language_names ();
+
+  for (i = 0; langs[i]; i++)
+    {
+      lang = langs[i];
+      if (strchr (lang, '.')) 
+          continue;
+
+      if (uri)
+	g_free (uri);
+
+      uri = g_build_filename (DATADIR, "/gnome/help/vinagre/", lang, "/vinagre.xml", NULL);
+					
+      if (g_file_test (uri, G_FILE_TEST_EXISTS))
+          break;
+    }
+	
+  command = g_strconcat ("gnome-open ghelp://", uri,  NULL);
+	
+  gdk_spawn_command_line_on_screen (gtk_window_get_screen (GTK_WINDOW (window)),
+				    command,
+				    &error);
+  if (error != NULL) 
+    {
+      vinagre_utils_show_error (error->message, GTK_WINDOW (window));
+      g_error_free (error);
+    }
+
+  g_free (command);
+  g_free (uri);
+}
+
 void
 vinagre_cmd_help_about (GtkAction     *action,
 			VinagreWindow *window)
@@ -325,6 +400,10 @@ vinagre_cmd_help_about (GtkAction     *action,
   license_trans = g_strjoin ("\n\n", _(license[0]), _(license[1]),
 				     _(license[2]), NULL);
 
+  /* Make URLs and email clickable in about dialog */
+  gtk_about_dialog_set_url_hook (vinagre_about_dialog_handle_url, window, NULL);
+  gtk_about_dialog_set_email_hook (vinagre_about_dialog_handle_url, window, NULL);
+
 
   gtk_show_about_dialog (GTK_WINDOW (window),
 			 "authors", authors,
@@ -341,4 +420,5 @@ vinagre_cmd_help_about (GtkAction     *action,
 			 NULL);
   g_free (license_trans);
 }
+
 /* vim: ts=8 */
